@@ -1,12 +1,7 @@
-#  tests for pyimagej-1.1.1-py37h03978a9_0 (this is a generated file);
-print('===== testing package: pyimagej-1.1.1-py37h03978a9_0 =====');
+#  tests for pyimagej-1.2.0-py37h03978a9_0 (this is a generated file);
+print('===== testing package: pyimagej-1.2.0-py37h03978a9_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
-import sys
-# Work around Java installation issues in CI
-if sys.platform == 'darwin':
-    sys.exit(0)
-
 import imagej
 import numpy as np
 
@@ -25,7 +20,7 @@ assert rai.dimension(0) == img_shape[0]
 assert rai.dimension(1) == img_shape[1]
 #  --- run_test.py (end) ---
 
-print('===== pyimagej-1.1.1-py37h03978a9_0 OK =====');
+print('===== pyimagej-1.2.0-py37h03978a9_0 OK =====');
 print("import: 'imagej'")
 import imagej
 
